#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_BITWISE_CAST_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_BITWISE_CAST_HPP_INCLUDED

#include <nt2/memory/include/functions/scalar/bitwise_cast.hpp>

#endif
